
{*******************************************************}
{                                                       }
{       Borland Delphi Visual Component Library         }
{       TWavePlayer property editor                     }
{                                                       }
{       Copyright (c) 1998-2000 Vino Rodrigues          }
{       vinorodrigues@yahoo.com                         }
{                                                       }
{       Version History:                                }
{       ----------------                                }
{                                                       }
{       1.1  30-Aug-01                                  }
{            First time I included "version history".   }
{                                                       }
{*******************************************************}

unit WaveEd;

{$D-,C-,Q-,Y-,L-}

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Wave,
  ExtCtrls, Dialogs, StdCtrls;

type
  TFormWaveEditor = class(TForm)
    OpenDialog: TOpenDialog;
    SaveDialog: TSaveDialog;
    BtnOk: TButton;
    BtnCancel: TButton;
    BtnHelp: TButton;
    BtnLoad: TButton;
    BtnSave: TButton;
    BtnClear: TButton;
    BtnPlay: TButton;
    BevelMain: TBevel;
    LabelInfo: TLabel;
    LabelSize: TLabel;
    RadioGroupSync: TRadioGroup;
    GroupBoxOptions: TGroupBox;
    CheckBoxLoop: TCheckBox;
    CheckBoxNoDefault: TCheckBox;
    CheckBoxNoStop: TCheckBox;
    CheckBoxNoWait: TCheckBox;
    procedure BtnLoadClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure BtnSaveClick(Sender: TObject);
    procedure BtnClearClick(Sender: TObject);
    procedure BtnPlayClick(Sender: TObject);
    procedure BtnStopClick(Sender: TObject);
  private
    FWave: TWave;
    procedure WaveChange(Sender: TObject);
    function GetOptions: TWaveOptions;
    function GetSync: TWaveSync;
    procedure SetOptions(const Value: TWaveOptions);
    procedure SetSync(const Value: TWaveSync);
  public
    property Wave: TWave read FWave;
    property Options: TWaveOptions read GetOptions write SetOptions;
    property Sync: TWaveSync read GetSync write SetSync;
  end;

var
  FormWaveEditor: TFormWaveEditor;

implementation

resourcestring
  sNone = '(Empty)';
  sSize = '%0.0n bytes';

{$R *.DFM}

{ TWaveEditor }

procedure TFormWaveEditor.FormCreate(Sender: TObject);
begin
  FWave := TWave.Create;
  FWave.OnChange := WaveChange;
  WaveChange(Self);
end;

procedure TFormWaveEditor.FormDestroy(Sender: TObject);
begin
  FWave.Stop;
  FWave.Free;
end;

procedure TFormWaveEditor.WaveChange(Sender: TObject);
var  sz: Double;
begin
  if FWave.Size = 0 then
  begin
    BtnPlay.Enabled := False;
    BtnSave.Enabled := False;
    BtnClear.Enabled := False;
    LabelSize.Caption := sNone;
  end
  else
  begin
    BtnPlay.Enabled := True;
    BtnSave.Enabled := True;
    BtnClear.Enabled := True;
    sz := FWave.Size;
    LabelSize.Caption := Format(sSize, [sz]);
  end;
end;

procedure TFormWaveEditor.BtnLoadClick(Sender: TObject);
begin
  if OpenDialog.Execute then
    FWave.LoadFromFile(OpenDialog.FileName);
end;

procedure TFormWaveEditor.BtnSaveClick(Sender: TObject);
begin
  if SaveDialog.Execute then
    FWave.SaveToFile(SaveDialog.FileName);
end;

procedure TFormWaveEditor.BtnClearClick(Sender: TObject);
begin
  FWave.Clear;
end;

procedure TFormWaveEditor.BtnPlayClick(Sender: TObject);
begin
  FWave.Sync := sndASync;
  FWave.Play;
end;

procedure TFormWaveEditor.BtnStopClick(Sender: TObject);
begin
  FWave.Stop;
end;

function TFormWaveEditor.GetOptions: TWaveOptions;
begin
  Result := [];
  if CheckBoxLoop.Checked then Include(Result, sndLoop);
  if CheckBoxNoDefault.Checked then Include(Result, sndNoDefault);
  if CheckBoxNoStop.Checked then Include(Result, sndNoStop);
  if CheckBoxNoWait.Checked then Include(Result, sndNoWait);
end;

function TFormWaveEditor.GetSync: TWaveSync;
begin
  if RadioGroupSync.ItemIndex = 1 then
    Result := sndASync
  else
    Result := sndSync;
end;

procedure TFormWaveEditor.SetOptions(const Value: TWaveOptions);
begin
  CheckBoxLoop.Checked := sndLoop in Value;
  CheckBoxNoDefault.Checked := sndNoDefault in Value;
  CheckBoxNoStop.Checked := sndNoStop in Value;
  CheckBoxNoWait.Checked := sndNoWait in Value;
end;

procedure TFormWaveEditor.SetSync(const Value: TWaveSync);
begin
  RadioGroupSync.ItemIndex := Ord(Value);
end;

end.
